Attribute VB_Name = "mdlCellsDemo"
Option Explicit

Public MyRegion As String ' Declared at a module level so it can be preserved across separate macros

Sub RegionExporter()
    
    ' This macro takes a piece of data (a Region in this case) and exports that region to its own sheet.
    ' The key takeaway to look out for is the Cells property. When paired with variables it is extremely
    ' powerful. It does not use the cursor so runs very fast, and is able to manipulate data easily with
    ' a single line of code. When you need to move data between sheets, see if Cells can be used.
    
    ' There are many places this can be improved. You could find out from the user which Region to work on,
    ' or even find out how many Regions there are, and then export them all individually... Headings and
    ' formatting are also ignored in this macro.
    
    ' VARABLE DECLARATIONS
    ' Which row on the source data we are working from
    Dim intRowCount As Integer

    ' Which column are we currently working on (used on source and target)
    Dim intColumnCount As Integer

    ' Keep track of how many rows we are up to on the target data
    Dim intTargetRowCount As Integer
    
    Sheets.Add
    
    MyRegion = "Asia"
    
    ' Runs the DeleteSheet macro (see below)
    Call DeleteSheet
    
    ActiveSheet.Name = MyRegion
    
    Sheets("SalesExport").Select
    
        intTargetRowCount = 2 ' Starts at row 2 - first row was for headings

        ' ActiveCell.CurrentRegion.Rows.Count is an effective way to figure out how big a dataset is
        For intRowCount = 1 To Sheets("SalesExport").Range("A5").CurrentRegion.Rows.Count
    
            ' If the current row's Region cell is what we're looking for then...
            If Sheets("SalesExport").Range("A5").Cells(intRowCount, 7).Value = MyRegion Then
        
                'Loop through every column in the row
                For intColumnCount = 1 To 11
                
                    ' This is a copy-and-paste process but much more efficient.
                    ' Note use of the variables to copy the relative position of the
                    ' source and target rows.
                    Sheets(MyRegion).Cells(intTargetRowCount, intColumnCount).Value = _
                        Sheets("SalesExport").Range("A5").Cells(intRowCount, intColumnCount).Value
                
                Next intColumnCount
                
                intTargetRowCount = intTargetRowCount + 1
        
            End If
 
        Next intRowCount

End Sub
Sub DeleteSheet()

Dim wstWorksheet As Worksheet

For Each wstWorksheet In ActiveWorkbook.Worksheets

    If wstWorksheet.Name = MyRegion Then
        
        Application.DisplayAlerts = False
        
        wstWorksheet.Delete
        
        Application.DisplayAlerts = True
        
        Exit For
        
    End If

Next wstWorksheet

End Sub
